==> qmmp-1.5.4.tar.bz2: qmmp-1.5.4/src/plugins/General/library/translations/library_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Library</name>
    <message>
        <location filename="../library.cpp" line="65"/>
        <source>Library</source>
        <translation>Kirjasto</translation>
    </message>
    <message>
        <location filename="../library.cpp" line="66"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../library.cpp" line="72"/>
        <source>Update library</source>
        <translation>Päivitä kirjasto</translation>
    </message>
    <message>
        <location filename="../library.cpp" line="193"/>
        <location filename="../library.cpp" line="194"/>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
</context>
<context>
    <name>LibraryFactory</name>
    <message>
        <location filename="../libraryfactory.cpp" line="33"/>
        <source>Media Library Plugin</source>
        <translation>Mediakirjastoliitännäinen</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="38"/>
        <source>Library</source>
        <translation>Kirjasto</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="38"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="84"/>
        <source>About Media Library Plugin</source>
        <translation>Tietoja: Media Library Plugin</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="85"/>
        <source>Qmmp Media Library Plugin</source>
        <translation>Qmmp Media Library Plugin</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="86"/>
        <source>This plugin represents a database to store music files tags for a fast access</source>
        <translation>Tämä laajennus edustaa tietokantaa musiikkitiedostojen tunnisteiden nopeaa käyttöä varten</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="87"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LibraryModel</name>
    <message>
        <location filename="../librarymodel.cpp" line="204"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>LibraryWidget</name>
    <message>
        <location filename="../librarywidget.cpp" line="51"/>
        <source>&amp;Add to Playlist</source>
        <translation>&amp;Lisää soittolistaan</translation>
    </message>
    <message>
        <location filename="../librarywidget.cpp" line="52"/>
        <source>&amp;View Track Details</source>
        <translation>Näy&amp;tä kappaleen tiedot</translation>
    </message>
    <message>
        <location filename="../librarywidget.cpp" line="54"/>
        <source>Quick Search</source>
        <translation>Pikahaku</translation>
    </message>
    <message>
        <location filename="../librarywidget.cpp" line="88"/>
        <source>Scanning directories...</source>
        <translation>Kartoitetaan kansioita...</translation>
    </message>
    <message>
        <location filename="../librarywidget.ui" line="14"/>
        <source>Media Library</source>
        <translation>Mediakirjasto</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Media Library Settings</source>
        <translation>Asetukset Media Library</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Recreate database</source>
        <translation>Luo tietokanta uudelleen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Show album year</source>
        <translation>Näytä albumin vuosi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>List of directories for scanning:</source>
        <translation>Luettelo läpikäytävistä kansioista:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="65"/>
        <source>Select Directories for Scanning</source>
        <translation>Valitse kansiot läpikäyntiä varten</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/library/translations/library_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Library</name>
    <message>
        <location filename="../library.cpp" line="65"/>
        <source>Library</source>
        <translation>Kirjasto</translation>
    </message>
    <message>
        <location filename="../library.cpp" line="66"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../library.cpp" line="72"/>
        <source>Update library</source>
        <translation>Päivitä kirjasto</translation>
    </message>
    <message>
        <location filename="../library.cpp" line="193"/>
        <location filename="../library.cpp" line="194"/>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
</context>
<context>
    <name>LibraryFactory</name>
    <message>
        <location filename="../libraryfactory.cpp" line="33"/>
        <source>Media Library Plugin</source>
        <translation>Media Library Plugin</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="38"/>
        <source>Library</source>
        <translation>Kirjasto</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="38"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="84"/>
        <source>About Media Library Plugin</source>
        <translation>Tietoja: Media Library Plugin</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="85"/>
        <source>Qmmp Media Library Plugin</source>
        <translation>Qmmp Media Library Plugin</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="86"/>
        <source>This plugin represents a database to store music files tags for a fast access</source>
        <translation>Tämä laajennus edustaa tietokantaa musiikkitiedostojen tunnisteiden nopeaa käyttöä varten</translation>
    </message>
    <message>
        <location filename="../libraryfactory.cpp" line="87"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LibraryModel</name>
    <message>
        <location filename="../librarymodel.cpp" line="204"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>LibraryWidget</name>
    <message>
        <location filename="../librarywidget.cpp" line="51"/>
        <source>&amp;Add to Playlist</source>
        <translation>&amp;Lisää soittolistaan</translation>
    </message>
    <message>
        <location filename="../librarywidget.cpp" line="52"/>
        <source>&amp;View Track Details</source>
        <translation>Näy&amp;tä kappaleen tiedot</translation>
    </message>
    <message>
        <location filename="../librarywidget.cpp" line="54"/>
        <source>Quick Search</source>
        <translation>Pikahaku</translation>
    </message>
    <message>
        <location filename="../librarywidget.cpp" line="88"/>
        <source>Scanning directories...</source>
        <translation>Kartoitetaan kansioita...</translation>
    </message>
    <message>
        <location filename="../librarywidget.ui" line="14"/>
        <source>Media Library</source>
        <translation>Media Library</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Media Library Settings</source>
        <translation>Asetukset Media Library</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Recreate database</source>
        <translation>Luo tietokanta uudelleen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Show album year</source>
        <translation>Näytä albumin vuosi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>List of directories for scanning:</source>
        <translation>Luettelo läpikäytävistä kansioista:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="65"/>
        <source>Select Directories for Scanning</source>
        <translation>Valitse kansiot läpikäyntiä varten</translation>
    </message>
</context>
</TS>
